developerscripttools.AbjDevScript
=================================

.. inheritance-diagram:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript
   :private-bases:

.. autoclass:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.alias

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.argument_parser

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.developer_script_aliases

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.developer_script_classes

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.developer_script_program_names

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.formatted_help

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.formatted_usage

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.formatted_version

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.long_description

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.program_name

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.scripting_group

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.short_description

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.version

Methods
-------

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.process_args

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.setup_argument_parser

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.__call__

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
